@@ -52,6 +52,7 @@ from flask_caching import Cache
 from flask_sqlalchemy import SQLAlchemy
 from flask_user import current_user, login_required, UserManager, UserMixin
 
+from werkzeug.routing import BaseConverter
 from werkzeug.security import generate_password_hash, check_password_hash
 from werkzeug.utils import secure_filename
 
@@ -138,6 +139,7 @@ if not os.path.exists(_PERVANE_CONFIG_DIR):
 _SQLITE_PATH = 'sqlite:///' + os.path.join(
     _PERVANE_CONFIG_DIR, 'pervane.sqlite')
 logging.info('db path: ', _SQLITE_PATH)
+print('db path: ', _SQLITE_PATH)
 
 # This is for editor to render with higher fidelity with per
 # language colors.
@@ -195,6 +197,14 @@ app.config.from_object(__name__+'.ConfigClass')
 # Initialize Flask-SQLAlchemy.
 db = SQLAlchemy(app)
 
+# Regex url matcher.
+class regex_converter(BaseConverter):
+  def __init__(self, url_map, *items):
+    super(regex_converter, self).__init__(url_map)
+    self.regex = items[0]
+
+app.url_map.converters['regex'] = regex_converter 
+
 # Define the User data-model.
 # NB: Make sure to add flask_user UserMixin !!!
 class User(db.Model, UserMixin):
@@ -458,7 +468,6 @@ def api_get_tree_handler():
 
 
 @app.route('/api/get_content')
-
 @login_required
 def api_get_content_handler():
   path = request.args.get('f', '').strip()
@@ -686,23 +695,25 @@ def api_search_handler():
 def api_glob_handler():
   root_dir = _get_root_dir()
   directory_path = request.args.get('f', '')
-  if not directory_path:
+  if not directory_path or '..' in directory_path:
     return 'You need to glob in a directory'
-  print('globbing: ', directory_path)
   # Need to eliminate first / in the parameter because we convert 
   # the actual paths to workspace paths for extra security.
   # /foo/bar and /test/baz are not joinable. os.path.join results with
   # /test/baz.
   glob_root = os.path.join(root_dir, directory_path[1:])
+
+  if not glob_root.startswith(root_dir) or '..' in glob_root:
+    logging.info('no auth')
+    return 'Not authorized to see this dir' 
+
   # TODO(hakanu): would os.walk be better?
   raw_files = os.listdir(glob_root)
   files = []
   dirs = []
-  print('found ', len(raw_files))
   for raw_file in raw_files:
     # Create an actual path to check if it's a directory.
     raw_file = os.path.join(glob_root, raw_file)
-    print('raw_file: ', raw_file)
     if os.path.isdir(raw_file):
       dirs.append(raw_file.replace(_WORKING_DIR, ''))
       continue
@@ -757,7 +768,7 @@ def file_upload_handler():
     })
 
 
-@app.route('/img/<path:file_path>', methods=['GET'])
+@app.route('/_img/<path:file_path>', methods=['GET'])
 @login_required
 def static_file_handler(file_path):
   """Incoming file path is under users working dir.
@@ -769,10 +780,14 @@ def static_file_handler(file_path):
   http://localhost:5001/img/test/images/apple-touch-icon.png
   http://localhost:5001/img/test/test_video/video.mp4
   """
-  print('serving from directory', file_path)
-  print('root', _get_root_dir())
   if not file_path:
     return 'You need to pass a file path to be served'
+
+  path = os.path.join(_WORKING_DIR, file_path[1:])
+  root_dir = _get_root_dir()
+  if not path.startswith(root_dir) or '..' in path:
+    logging.info('no auth')
+    return 'Not authorized to see this dir' 
   return send_from_directory(_get_root_dir(),
                              file_path)
 
